@@ -15,6 +15,7 @@
 #include <QMessageBox>
 #include <QPointer>
 #include <QIcon>
+#include <QRegularExpression>
 
 //__________________________________________________________
 namespace Breeze
@@ -307,7 +308,7 @@ namespace Breeze
     bool ExceptionListWidget::checkException( InternalSettingsPtr exception )
     {
 
-        while( exception->exceptionPattern().isEmpty() || !QRegExp( exception->exceptionPattern() ).isValid() )
+        while( exception->exceptionPattern().isEmpty() || !QRegularExpression( exception->exceptionPattern() ).isValid() )
         {
 
             QMessageBox::warning( this, i18n( "Warning - Breeze Settings" ), i18n("Regular Expression syntax is incorrect") );
