@@ -121,6 +121,8 @@ namespace Breeze {
                 }
             }
         }
+
+        _colorSchemeHasHeaderColor =  KColorScheme::isColorSetSupported(_config, KColorScheme::Header);
     }
 
     bool AppListener::eventFilter(QObject *watched, QEvent *event)
@@ -239,4 +241,9 @@ namespace Breeze {
             _windows[mainWindow].removeAll(toolbar);
         }
     }
+
+    bool Breeze::ToolsAreaManager::hasHeaderColors()
+    {
+        return _colorSchemeHasHeaderColor;
+    }
 }
