@@ -37,6 +37,7 @@ namespace Breeze {
         KConfigWatcher::Ptr _watcher;
         QPalette _palette = QPalette();
         AppListener* _listener;
+        bool _colorSchemeHasHeaderColor;
 
         friend class AppListener;
 
@@ -58,6 +59,8 @@ namespace Breeze {
         void unregisterWidget(QWidget *widget);
 
         QRect toolsAreaRect(const QMainWindow *window);
+
+        bool hasHeaderColors();
     };
 }
 
